@@ -1,8 +1,9 @@
-import distutils.version
-
-import astropy
-
 # Import pfsspy sub-modules to have them available through pfsspy.{name}
+try:
+    import pfsspy.analytic
+except ModuleNotFoundError:
+    # If sympy isn't installed
+    pass
 import pfsspy.coords
 import pfsspy.fieldline
 # Import this to register map sources
@@ -10,6 +11,7 @@ import pfsspy.map
 import pfsspy.sample_data
 import pfsspy.tracing
 import pfsspy.utils
+
 from .input import Input
 from .output import Output
 from .pfss import pfss
@@ -22,12 +24,6 @@ from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-# Do a version check for astropy
-if (distutils.version.LooseVersion(astropy.__version__) <
-        distutils.version.LooseVersion("3")):
-    raise RuntimeError('pfsspy requires astropy v3 to run ' +
-                       f'(found version {astropy.__version__} installed)')
-
 
 __citation__ = __bibtex__ = """
 @article{Stansby2020,
